@@ -1,14 +1,15 @@
-lvsplot <- function(x, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.5, main = NULL, 
+lvsplot <- function(object, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.5, main = NULL, 
      est = "median", which.lvs = c(1,2), return.vals = FALSE, ...) {
 
-     if(x$num.lv == 0) 
+     if(object$num.lv == 0) 
           stop("No latent variables to plot.")
      if(length(which.lvs) != 2) 
-          stop("which.lvs should be a vector of length 2, indicating which axes to plot. This argument is ignored if x$num.lv = 1.")
-     if(x$num.lv > 2 & any(which.lvs > x$num.lv)) 
+          stop("which.lvs should be a vector of length 2, indicating which axes to plot. This argument is ignored if object$num.lv = 1.")
+     if(object$num.lv > 2 & any(which.lvs > object$num.lv)) 
           stop("Fewer latent variables than chosen by which.lvs")
 
-     n <- nrow(x$lv.median); p <- nrow(x$lv.coefs.median)
+     n <- nrow(object$lv.median)
+     p <- nrow(object$lv.coefs.median)
      if(!is.null(ind.spp)) { 
           if(ind.spp > p) { ind.spp <- p } 
           }
@@ -19,13 +20,13 @@ lvsplot <- function(x, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.
           ind.spp <- p; message("All latent variable coefficients included in biplot.") 
           }
 
-     if(x$num.lv == 1) {
-          choose_lvs <- x$lv.median; 
-          choose_lvs_coefs <- x$lv.coefs.median[,2]
+     if(object$num.lv == 1) {
+          choose_lvs <- object$lv.median; 
+          choose_lvs_coefs <- object$lv.coefs.median[,2]
           main <- "Plot of latent variable posterior medians"
           if(est == "mean") { 
-               choose_lvs <- x$lv.mean
-               choose_lvs_coefs <- x$lv.coefs.mean[,2] 
+               choose_lvs <- object$lv.mean
+               choose_lvs_coefs <- object$lv.coefs.mean[,2] 
                }
 
           if(!biplot) {
@@ -35,9 +36,9 @@ lvsplot <- function(x, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.
                     main <- "Plot of latent variable posterior means"
                plot(1:n, choose_lvs, xlab = "Row index", ylab = "Latent variable 1", main = main, type = "n", ...)
                if(!jitter) 
-                    text(x = 1:n, y = x$lv.median, label = 1:n, ...)
+                    text(x = 1:n, y = object$lv.median, label = 1:n, ...)
                if(jitter) 
-                    text(x = 1:n, y = jitter(x$lv.median), label = 1:n, ...)
+                    text(x = 1:n, y = jitter(object$lv.median), label = 1:n, ...)
                }
 
           if(biplot) {
@@ -47,22 +48,22 @@ lvsplot <- function(x, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.
                     main <- "Biplot of latent variable posterior means" 
                plot(1:n, choose_lvs, xlab = "Row index", ylab = "Latent variable 1", main = main, type = "n", ...)
                if(!jitter) 
-                    text(x = 1:n, y = x$lv.median, label = 1:n, ...)
+                    text(x = 1:n, y = object$lv.median, label = 1:n, ...)
                if(jitter) 
-                    text(x = 1:n, y = jitter(x$lv.median), label = 1:n, ...)
-               text(choose_lv_coefs, label = rownames(x$lv.coefs.mean), col = "red", ...)	
+                    text(x = 1:n, y = jitter(object$lv.median), label = 1:n, ...)
+               text(choose_lv_coefs, label = rownames(object$lv.coefs.mean), col = "red", ...)	
                }
           }
 
 
-     if(x$num.lv > 1) {
-          testcov <- tcrossprod(x$lv.median, x$lv.coefs.median[,2:(x$num.lv+1)])
+     if(object$num.lv > 1) {
+          testcov <- tcrossprod(object$lv.median, object$lv.coefs.median[,2:(object$num.lv+1)])
           if(est == "mean") 
-               testcov <- tcrossprod(x$lv.mean, x$lv.coefs.mean[,2:(x$num.lv+1)])
+               testcov <- tcrossprod(object$lv.mean, object$lv.coefs.mean[,2:(object$num.lv+1)])
 
-          do_svd <- svd(testcov, x$num.lv, x$num.lv)   		
-          choose_lvs <- scale(do_svd$u*matrix(do_svd$d[1:x$num.lv]^alpha,nrow=x$n,ncol=x$num.lv,byrow=TRUE),center = TRUE, scale = FALSE)
-          choose_lv_coefs <- scale(do_svd$v*matrix(do_svd$d[1:x$num.lv]^(1-alpha),nrow=x$p,ncol=x$num.lv,byrow=TRUE), center = TRUE, scale = FALSE)
+          do_svd <- svd(testcov, object$num.lv, object$num.lv)   		
+          choose_lvs <- scale(do_svd$u*matrix(do_svd$d[1:object$num.lv]^alpha,nrow=object$n,ncol=object$num.lv,byrow=TRUE),center = TRUE, scale = FALSE)
+          choose_lv_coefs <- scale(do_svd$v*matrix(do_svd$d[1:object$num.lv]^(1-alpha),nrow=object$p,ncol=object$num.lv,byrow=TRUE), center = TRUE, scale = FALSE)
           
           if(!biplot) {
                if(is.null(main) & est == "median") 
@@ -88,7 +89,7 @@ lvsplot <- function(x, jitter = FALSE, biplot = TRUE, ind.spp = NULL, alpha = 0.
                     text(choose_lvs[,which.lvs], label = 1:n, ...)
                if(jitter) 
                     text(jitter(choose_lvs[,which.lvs[1]]), jitter(choose_lvs[,which.lvs[2]]), label = 1:n, ...)
-               text(choose_lv_coefs[largest.lnorms,which.lvs], label = rownames(x$lv.coefs.mean[largest.lnorms,]), col = "red", ...)	
+               text(choose_lv_coefs[largest.lnorms,which.lvs], label = rownames(object$lv.coefs.mean[largest.lnorms,]), col = "red", ...)	
                }
           }	
 
